
*********************************************************************************
*****************  For analysis with aggregate precinct-level data   ************
*********************************************************************************

/* This do file runs the analysis with aggregate data of Chong et al. 2015 "Does Corruption Information Inspire the Fight or 
Quash the Hope? A Field Experiment in Mexico on Voter Turnout, Choice, and Party Identification. JOP.
Please contact ana.delao@yale.edu for any questions */



**Call data set
clear
cd "/Users/anadelao/Dropbox/CorruptionInfo/Data and Do files/Replication files"
use "Chongetal_aggregate_JOP.dta", clear
	

/*Generate additional variables needed for analysis*/

/*Labels for treatment and placebo groups*/
	**No information
	gen t0=(treatment==0)
	**Placebo
	gen t1=(treatment==1|treatment==2)
	**Treatment corruption
	rename treatment3 t3

/*Poverty index*/
	for X in any anal05 spri05 sdye05 see05 sagua05 srefri05 pisotie05:  egen SX = std(X)
	egen ISpovertytemp = rsum(S*)
	egen ISpoverty=std(ISpovertytemp)

/*Dummies for corruption bins 33 66 100*/
	gen corr33=(t3_info<float(.33))
	gen corr66=(t3_info>=float(.33) & t3_info<float(.66))
	gen corr100=(t3_info>=float(.66))

/*Interactions with corruption bins 33 66 100*/
	gen corr33t=corr33*t3
	gen corr66t=corr66*t3
	gen corr100t=corr100*t3

/*Quadratic term */
	gen t3_2=t3_info^2

/*Interactions with corruption linear and quadratic*/
	gen t3Xlinear=t3*t3_info
	gen t3Xquad=t3*t3_2

/*Define challengers' last job (as a proxy for quality)*/
**Challenger was ``diputado local con licencia''
	gen chall_dip=0
	replace chall_dip=1 if estado=="Jalisco" & municipality!="TLAQUEPAQUE" & municipality!="GUADALAJARA"
	replace chall_dip=1 if municipality=="CUAUTLA" 

/*Define municipalities that are state capitals*/
	gen capital=(municipality=="CENTRO"| municipality=="CUERNAVACA"| municipality=="GUADALAJARA") 

/*Define municipalities where fail to treat was more than 30 percent*/
	tab municipality, sum (perc_treated)
	gen fail_tt=(municipality=="CUAUTLA"| municipality=="CRDENAS" | municipality=="HUIMANGUILLO")

*********************************************************************************
*****************      Descriptive Statistics          **************************
*********************************************************************************

foreach var of varlist anal05 spri05 sdye05 see05 sagua05 pisotie05 srefri05 ISpoverty {
	sum `var' 
}


foreach var of varlist t2009 t2006 {
	replace `var'=100 if `var'>100 & `var'!=. 
}

foreach var of varlist t2009 inc_vs2009 challengers_vs2009 t2006 inc_vs2006 challengers_vs2006 {
	sum `var' 
}


*********************************************************************************
*****************  Testing validity of randomization   **************************
*********************************************************************************

/* Balance in baseline characteristics-- Comparing means */ 
forval i= 0 (1) 3 {
	sum  anal05 spri05 sdye05 see05 sagua05 pisotie05 srefri05 t2006 inc_vs2006 challengers_vs2006  if treatment==`i'
}

/* Testing validity of randomization including municipality fixed effects*/ 
	foreach lhs in  anal05 spri05 sdye05 see05 sagua05 pisotie05 srefri05 t2006 inc_vs2006 challengers_vs2006 {
		xi: areg `lhs' i.treatment, absorb(municipality) 
	}

/*Note randomization still valid if we combine placebo groups into one*/
	foreach lhs in  anal05 spri05 sdye05 see05 sagua05 pisotie05 srefri05 t2006 inc_vs2006 challengers_vs2006 {
		xi: areg `lhs' t1 t3, absorb(municipality) 
	}
	
	foreach lhs in t1 t3 {
		xi: areg `lhs' anal05 spri05 sdye05 see05 sagua05 pisotie05 srefri05 t2006 inc_vs2006 challengers_vs2006, absorb(municipality) 
	}

*****************************************************************
****************** TABLES WITH AGGREGATE PRECINT LEVEL DATA *****        
*****************************************************************

/* Main results use WLS with weights defined by inverse of probability of treatment
 to take into account the block randomization (following Green and Gerber) */ 

/*Define weights*/ 
*for each treatment subject, compute the proportion of subjects in the same block who were assigned to treatment
gen temp=1
gen control=(treatment==0)

by municipality, sort: egen obs_mun=total(temp)

by municipality, sort: egen obs_t1=total(treatment1)
by municipality, sort: egen obs_t2=total(treatment2)
by municipality, sort: egen obs_t3=total(t3)

by municipality, sort: gen pt1=obs_t1/obs_mun
by municipality, sort: gen pt2=obs_t2/obs_mun
by municipality, sort: gen pt3=obs_t3/obs_mun

*for control subjects, compute the proportion of subjects in the same block who were assigned to control
by municipality, sort: egen obs_control=total(control)
by municipality, sort: gen pt0=obs_control/obs_mun

*call this variable q
gen q=.
by municipality, sort: replace q=pt1 if treatment==1
by municipality, sort: replace q=pt2 if treatment==2
by municipality, sort: replace q=pt3 if treatment==3
by municipality, sort: replace q=pt0 if treatment==0

**regress outcomes on treatment, weighting each observation by 1/q 	

/*Table 4: Main results*/ 

/* Columns 1-3: Turnout*/
	areg t2009 t3 t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, replace tex ctitle("Turnout") dec(2)  2aster
	test t3=t0
	areg t2009 t3 t3Xlinear t3Xquad t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg t2009 corr33t corr66t corr100t t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test corr33t=corr66t
	test corr33t=corr100t
	test corr66t=corr100t
	test corr33t corr66t corr100t 
			
/*Columns 4-6: Incumbent*/
	areg inc_vs2009 t3 t0 [w=1/q], absorb(municipality)
	outreg2 using w_agg, append tex ctitle("Incumbent") dec(2)  2aster
	test t3=t0
	areg inc_vs2009 t3 t3Xlinear t3Xquad t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg inc_vs2009 corr33t corr66t corr100t t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test corr33t=corr66t
	test corr33t=corr100t
	test corr66t=corr100t
	test corr33t corr66t corr100t 	
	
/*Columns 7-9: Challenger*/
	areg challengers_vs2009 t3 t0 [w=1/q], absorb(municipality) 
	test t3=t0
	outreg2 using w_agg, append tex ctitle("Challenger") dec(2) 2aster
	areg challengers_vs2009 t3 t3Xlinear t3Xquad t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg challengers_vs2009 corr33t corr66t corr100t t0 [w=1/q], absorb(municipality) 
	outreg2 using w_agg, append tex ctitle("") dec(2) 2aster
	test corr33t=corr66t
	test corr33t=corr100t
	test corr66t=corr100t
	test corr33t corr66t corr100t 	

/*Testing coefficients across equations incumbent and challenger */

tab municipality, gen (m)

	reg inc_vs2009 t3 t0 m1-m11 [w=1/q]
	est store eqn1
	reg challengers_vs2009 t3 t0 m1-m11 [w=1/q]
	est store eqn2
	suest eqn1 eqn2 
	test [eqn1_mean]t3=[eqn2_mean]t3
	
	reg inc_vs2009 t3 t3Xlinear t3Xquad t0 m1-m11 [w=1/q]
	est store eqn1
	reg challengers_vs2009 t3 t3Xlinear t3Xquad t0 m1-m11 [w=1/q]
	est store eqn2
	suest eqn1 eqn2 
	test [eqn1_mean]t3=[eqn2_mean]t3
	test [eqn1_mean]t3Xlinear=[eqn2_mean]t3Xlinear
	test [eqn1_mean]t3Xquad=[eqn2_mean]t3Xquad
	
	reg inc_vs2009 corr33t corr66t corr100t t0 m1-m11 [w=1/q]
	est store eqn1
	reg challengers_vs2009 corr33t corr66t corr100t t0 m1-m11 [w=1/q]
	est store eqn2
	suest eqn1 eqn2 
	test [eqn1_mean]corr33t=[eqn2_mean]corr33t
	test [eqn1_mean]corr66t=[eqn2_mean]corr66t
	test [eqn1_mean]corr100t=[eqn2_mean]corr100t
	

	
/*Table 5: Heterogenous effects based on whether challenger was a "diputado local"*/

	xi: areg t2009 i.t3*chall_dip t0 [w=1/q], absorb(municipality) 
	test _It3_1+_It3Xchall_1=0
	outreg2 using het, replace tex ctitle ("Turnout") dec(2) 2aster
	
	xi: areg inc_vs2009 i.t3*chall_dip t0 [w=1/q], absorb(municipality) 
	test _It3_1+_It3Xchall_1=0
	outreg2 using het, append tex ctitle ("Incumbent") dec(2) 2aster
	
	xi: areg challengers_vs2009 i.t3*chall_dip t0 [w=1/q], absorb(municipality) 
	test _It3_1+_It3Xchall_1=0
	outreg2 using het, append tex ctitle ("Challenger") dec(2) 2aster

	
******************************************************
************* Supplemental Information  **************
*******************************************************

/*Table A1: Estimates without the weights*/

/* Turnout*/
	areg t2009 t3 t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, replace tex ctitle("Turnout") dec(2) 2aster
	areg t2009 t3 t3Xlinear t3Xquad t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg t2009 corr33t corr66t corr100t t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
		
/* Incumbent*/
	areg inc_vs2009 t3 t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("Incumbent") dec(2) 2aster
	areg inc_vs2009 t3 t3Xlinear t3Xquad t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg inc_vs2009 corr33t corr66t corr100t t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
	
/* Challenger*/
	areg challengers_vs2009 t3 t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("Challenger") dec(2) 2aster
	areg challengers_vs2009 t3 t3Xlinear t3Xquad t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
	test t3 t3Xlinear t3Xquad
	areg challengers_vs2009 corr33t corr66t corr100t t0, absorb(municipality) cluster(municipality)
	outreg2 using main_agg, append tex ctitle("") dec(2) 2aster
	
/* Table A2: Estimates with baseline controls */

/* Turnout*/
	areg t2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality) 
	outreg2 using controls_agg, replace tex ctitle("Turnout") dec(2) 2aster
	areg t2009 t3 t3Xlinear t3Xquad t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb (municipality) 
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
	areg t2009 corr33t corr66t corr100t t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
    		
/* Incumbent*/
	areg inc_vs2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality) 
	outreg2 using controls_agg, append tex ctitle("Incumbent") dec(2) 2aster
	areg inc_vs2009 t3 t3Xlinear t3Xquad t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb (municipality)
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
	areg inc_vs2009 corr33t corr66t corr100t t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
	
/* Challenger*/
	areg challengers_vs2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality) 
	outreg2 using controls_agg, append tex ctitle("Challenger") dec(2) 2aster
	areg challengers_vs2009 t3 t3Xlinear t3Xquad t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality) 
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
	areg challengers_vs2009 corr33t corr66t corr100t t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)
	outreg2 using controls_agg, append tex ctitle("") dec(2) 2aster
    
/* Table A3: Estimates without state capitals, where spillovers may be greatest*/

/* Turnout*/
	areg t2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, replace tex ctitle("Turnout") dec(2) 2aster
	areg t2009 t3 t3Xlinear t3Xquad t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	areg t2009 corr33t corr66t corr100t t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	
/* Incumbent*/
	areg inc_vs2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("Incumbent") dec(2) 2aster
	areg inc_vs2009 t3 t3Xlinear t3Xquad t0 if capital!=1 [w=1/q], absorb(municipality)
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	areg inc_vs2009 corr33t corr66t corr100t t0 if capital!=1 [w=1/q], absorb(municipality)
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	
/* Challenger*/
	areg challengers_vs2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("Challenger") dec(2) 2aster
	areg challengers_vs2009 t3 t3Xlinear t3Xquad t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	areg challengers_vs2009 corr33t corr66t corr100t t0 if capital!=1 [w=1/q], absorb(municipality) 
	outreg2 using wcap_agg, append tex ctitle("") dec(2) 2aster
	
	
/* Table A4: Estimates without three municipalities where failure to treat was equal or higher than 30 percent */

/* Turnout*/
	areg t2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, replace tex ctitle("Turnout") dec(2) 2aster
	areg t2009 t3 t3Xlinear t3Xquad t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster
	areg t2009 corr33t corr66t corr100t t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster	

/* Incumbent*/
	areg inc_vs2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, append tex ctitle("Incumbent") dec(2) 2aster
	areg inc_vs2009 t3 t3Xlinear t3Xquad t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster
	areg inc_vs2009 corr33t corr66t corr100t t0 if fail_tt!=1 [w=1/q], absorb(municipality) 
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster
	
/* Challenger*/
	areg challengers_vs2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)
	outreg2 using fail_agg, append tex ctitle("Challenger") dec(2) 2aster
	areg challengers_vs2009 t3 t3Xlinear t3Xquad t0 if fail_tt!=1 [w=1/q], absorb(municipality)
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster
	areg challengers_vs2009 corr33t corr66t corr100t t0 if fail_tt!=1 [w=1/q], absorb(municipality)
	outreg2 using fail_agg, append tex ctitle("") dec(2) 2aster
	

/*Graphs*/

/*Turnout and treatment dummy*/	   
parmby "areg t2009 t3 t0 [w=1/q], absorb(municipality)", lab saving(tf1,replace) idn(2) ids(WLS)
parmby "areg t2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)", lab saving(tf2,replace) idn(1) ids(With controls)  
parmby "areg t2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality)", lab saving(tf3,replace) idn(3) ids(Without capitals)
parmby "areg t2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)", lab saving(tf4,replace) idn(4) ids(Without mpios>30% fail to treat)

parmby "areg inc_vs2009 t3 t0 [w=1/q], absorb(municipality)", lab saving(tf5,replace) idn(6) ids(WLS)
parmby "areg inc_vs2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)", lab saving(tf6,replace) idn(6) ids(With controls)
parmby "areg inc_vs2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality)", lab saving(tf7,replace) idn(7) ids(Without capitals)
parmby "areg inc_vs2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)", lab saving(tf8,replace) idn(8) ids(Without mpios>30% fail to treat)

parmby "areg challengers_vs2009 t3 t0 [w=1/q], absorb(municipality)", lab saving(tf9,replace) idn(10) ids(WLS)
parmby "areg challengers_vs2009 t3 t0 ISpoverty t2006 inc_vs2006 challengers_vs2006 [w=1/q], absorb(municipality)", lab saving(tf10,replace) idn(10) ids(With controls)
parmby "areg challengers_vs2009 t3 t0 if capital!=1 [w=1/q], absorb(municipality)", lab saving(tf11,replace) idn(11) ids(Without capitals)
parmby "areg challengers_vs2009 t3 t0 if fail_tt!=1 [w=1/q], absorb(municipality)", lab saving(tf12,replace) idn(12) ids(Without mpios>30% fail to treat)

dsconcat tf1 tf2 tf3 tf4 tf5 tf6 tf7 tf8 tf9 tf10 tf11 tf12


sencode idstr, gene(modtype)
sencode label, gene(predictor)
lab var modtype "Model"
lab var predictor "Predictor"
drop if predictor!=1

gen depvar=.
replace depvar=1 if idn<=4
replace depvar=2 if idn>4 & idn<=8
replace depvar=3 if idn>8 
label define outcomes 1 "Turnout" 2 "Incumbent" 3 "Challengers"
label values depvar outcomes
 
eclplot estimate min95 max95 depvar, hor supby(modtype, spaceby(0.25))

